searchData={"items":[{"type":"module","title":"Cabbage","doc":"","ref":"Cabbage.html"},{"type":"function","title":"Cabbage.base_path/0","doc":"","ref":"Cabbage.html#base_path/0"},{"type":"function","title":"Cabbage.global_tags/0","doc":"","ref":"Cabbage.html#global_tags/0"},{"type":"module","title":"Cabbage.Feature","doc":"An extension on ExUnit to be able to execute feature files.","ref":"Cabbage.Feature.html"},{"type":"module","title":"Configuration - Cabbage.Feature","doc":"In `config/test.exs`\n\n    config :cabbage,\n      # Default is \"test/features/\"\n      features: \"my/path/to/features/\"\n      # Default is []\n      global_tags: :integration\n\n- `features` - Allows you to specify the location of your feature files. They can be anywhere, but typically are located within the test folder.\n- `global_tags` - Allow you to specify ex unit tag assigned to all cabbage generated tests","ref":"Cabbage.Feature.html#module-configuration"},{"type":"module","title":"Features - Cabbage.Feature","doc":"Given a feature file, create a corresponding feature module which references it. Heres an example:\n\n    defmodule MyApp.SomeFeatureTest do\n      use Cabbage.Feature, file: \"some_feature.feature\"\n\n      defgiven ~r/I am given a given statement/, _matched_data, _current_state do\n        assert 1 + 1 == 2\n        {:ok, %{new: :state}}\n      end\n\n      defwhen ~r/I when execute it/, _matched_data, _current_state do\n        # Nothing to do, don't need to return anything if we don't want to\n        nil\n      end\n\n      defthen ~r/everything is ok/, _matched_data, _current_state do\n        assert true\n      end\n    end\n\nThis translates loosely into:\n\n    defmodule MyApp.SomeFeatureTest do\n      use ExUnit.Case\n\n      test \"The name of the scenario here\" do\n        assert 1 + 1 == 2\n        nil\n        assert true\n      end\n    end\n\n#","ref":"Cabbage.Feature.html#module-features"},{"type":"module","title":"Extracting Matched Data - Cabbage.Feature","doc":"You'll likely have data within your feature statements which you want to extract. The second parameter to each of `defgiven/4`, `defwhen/4` and `defthen/4` is a pattern in which specifies what you want to call the matched data, provided as a map.\n\nFor example, if you want to match on a number:\n\n    # NOTICE THE `number` VARIABLE IS STILL A STRING!!\n    defgiven ~r/^there (is|are) (? +) widget(s?)$/, %{number: number}, _state do\n      assert String.to_integer(number) >= 1\n    end\n\nFor every named capture, you'll have a key as an atom in the second parameter. You can then use those variables you create within your block.\n\n#","ref":"Cabbage.Feature.html#module-extracting-matched-data"},{"type":"module","title":"Modifying State - Cabbage.Feature","doc":"You'll likely have to keep track of some state in between statements. The third parameter to each of `defgiven/4`, `defwhen/4` and `defthen/4` is a pattern in which specifies what you want to call your state in the same way that the `ExUnit.Case.test/3` macro works.\n\nYou can setup initial state using plain ExUnit `setup/1` and `setup_all/1`. Whatever state is provided via the `test/3` macro will be your initial state.\n\nTo update the state, simply return `{:ok, %{new: :state}}`. Note that a `Map.merge/2` will be performed for you so only have to specify the keys you want to update. For this reason, only a map is allowed as state.\n\nHeres an example modifying state:\n\n    defwhen ~r/^I am an admin$/, _, %{user: user} do\n      {:ok, %{user: User.promote_to_admin(user)}}\n    end\n\nAll other statements do not need to return (and should be careful not to!) the `{:ok, state}` pattern.\n\n#","ref":"Cabbage.Feature.html#module-modifying-state"},{"type":"module","title":"Organizing Features - Cabbage.Feature","doc":"You may want to reuse several statements you create, especially ones that deal with global logic like users and logging in.\n\nFeature modules can be created without referencing a file. This makes them do nothing except hold translations between steps in a scenario and test code to be included into a test. These modules must be compiled prior to running the test suite, so for that reason you must add them to the `elixirc_paths` in your `mix.exs` file, like so:\n\n    defmodule MyApp.Mixfile do\n      use Mix.Project\n\n      def project do\n        [\n          app: :my_app,\n          ... # Add this to your project function\n          elixirc_paths: elixirc_paths(Mix.env),\n          ...\n        ]\n      end\n\n      # Specifies which paths to compile per environment.\n      defp elixirc_paths(:test), do: [\"lib\", \"test/support\"]\n      defp elixirc_paths(_),     do: [\"lib\"]\n\n      ...\n    end\n\nIf you're using Phoenix, this should already be setup for you. Simply place a file like the following into `test/support`.\n\n    defmodule MyApp.GlobalFeatures do\n      use Cabbage.Feature\n\n      # Write your `defgiven/4`, `defthen/4` and `defwhen/4`s here\n    end\n\nThen inside the test file (the .exs one) add a `import_feature MyApp.GlobalFeatures` line after the `use Cabbage.Feature` line lke so:\n\n    defmodule MyApp.SomeFeatureTest do\n      use Cabbage.Feature, file: \"some_feature.feature\"\n      import_feature MyApp.GlobalFeatures\n\n      # Omitted the rest\n    end\n\nKeep in mind that if you'd like to be more explicit about what you bring into your test, you can use the macros `import_steps/1` and `import_tags/1`. This will allow you to be more selective about whats getting included into your integration tests. The `import_feature/1` macro simply calls both the `import_steps/1` and `import_tags/1` macros.","ref":"Cabbage.Feature.html#module-organizing-features"},{"type":"function","title":"Cabbage.Feature.compile_step/3","doc":"","ref":"Cabbage.Feature.html#compile_step/3"},{"type":"macro","title":"Cabbage.Feature.defgiven/4","doc":"","ref":"Cabbage.Feature.html#defgiven/4"},{"type":"macro","title":"Cabbage.Feature.defthen/4","doc":"","ref":"Cabbage.Feature.html#defthen/4"},{"type":"macro","title":"Cabbage.Feature.defwhen/4","doc":"","ref":"Cabbage.Feature.html#defwhen/4"},{"type":"macro","title":"Cabbage.Feature.expose_metadata/1","doc":"","ref":"Cabbage.Feature.html#expose_metadata/1"},{"type":"macro","title":"Cabbage.Feature.import_feature/1","doc":"Brings in all the functionality available from the supplied module. Module must `use Cabbage.Feature` (with or without a `:file`).\n\nSame as calling both `import_steps/1` and `import_tags/1`.","ref":"Cabbage.Feature.html#import_feature/1"},{"type":"macro","title":"Cabbage.Feature.import_steps/1","doc":"Brings in all the step definitions from the supplied module. Module must `use Cabbage.Feature` (with or without a `:file`).","ref":"Cabbage.Feature.html#import_steps/1"},{"type":"macro","title":"Cabbage.Feature.import_tags/1","doc":"Brings in all the tag definitions from the supplied module. Module must `use Cabbage.Feature` (with or without a `:file`).","ref":"Cabbage.Feature.html#import_tags/1"},{"type":"macro","title":"Cabbage.Feature.tag/2","doc":"Add an ExUnit `setup/1` callback that only fires for the scenarios that are tagged. Can be\nused inside of `Cabbage.Feature`s that don't relate to a file and then imported with `import_feature/1`.\n\nExample usage:\n\n    defmodule MyTest do\n      use Cabbage.Feature\n\n      tag @some_tag do\n        IO.puts \"Do this before the @some_tag scenario\"\n        on_exit fn ->\n          IO.puts \"Do this after the @some_tag scenario\"\n        end\n      end\n    end","ref":"Cabbage.Feature.html#tag/2"},{"type":"module","title":"Cabbage.Feature.Loader","doc":"","ref":"Cabbage.Feature.Loader.html"},{"type":"function","title":"Cabbage.Feature.Loader.load_from_file/1","doc":"","ref":"Cabbage.Feature.Loader.html#load_from_file/1"},{"type":"function","title":"Cabbage.Feature.Loader.load_from_string/1","doc":"","ref":"Cabbage.Feature.Loader.html#load_from_string/1"},{"type":"exception","title":"Cabbage.Feature.MissingStepError","doc":"Raises an error, because a feature step is missing its implementation.\n\nThe message of the error will give the user a useful code snippet where\nvariables in feature steps are converted to regex capture groups.","ref":"Cabbage.Feature.MissingStepError.html"}],"content_type":"text/markdown"}